<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * QueryView class
 *
 * This is the class in charge for the dataquery result rendering.
 * It parses a cactiquery class object and produces clean and nice web output.
 *
 * PHP versions 4 and 5
 * 
 * @category   Cactiquery
 * @package    cacti
 * @subpackage dataquery
 * @author     Kostas Petrakis aka pestilence <petrakis@insert.gr>
 * @copyright  2006 Kostas Petrakis
 * @license GNU/GPL, see LICENSE.php
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @version $Id: queryview.php 2006-10-31 15:10 pestilence $
 * @version 0.1.4a
 * @link       http://webdev.insert.gr
 */

class QueryView
{
	var $queryObj				= null;

	function QueryView(&$cactiquery)
	{
		$this->queryObj =& $cactiquery;
		$this->create_csslink();
	}

	function &get_instance(&$cactiquery)
	{
		static $instance;
		if(!isset($instance[0]))
		{
			$instance[0] = new QueryView($cactiquery);
		}
		return $instance[0];
	}

	function create_csslink()
	{
		echo '<LINK href="css/dataquery.css" rel="stylesheet" type="text/css">';
	}

	function create_output()
	{
		$columns = count($this->queryObj->columns);
		$rows = count($this->queryObj->values['data']);
		//Add also timestamp to colspan
		$colspan = $columns + 1;
		print "<table width='90%' class='query' align='center'>";
		print "<tr width='100%' class='query_header'>";
		print "<td colspan='".$colspan."' class='query_data_source_header' align='center'><strong>Query for Datasource: '".$this->queryObj->data_source."</strong></td>";
		print "</tr>";
		print "</table>";
		print "<table width='90%' class='query' align='center'>";
		print "<tr width='100%' bgcolor='#6d88ad' class='query_header'>\n";
		//Get the colspan...
		print "<td class='td_query_header' align='center' width='20%'><strong>Timestamp</strong></td>";
		$v=0;
		$type = array();
		foreach ($this->queryObj->columns as $title)
		{
			print "<td align='center' class='td_query_header'><b>$title</b></td>";
			$type[$v] = $title;
			$v++;
		}
		print "</tr>\n";
		$valine = "";
		$col_row = 0;
		for ($j=0; $j<$rows; $j++)
		{
			if ( $col_row == 0 )
			{
				$row_color = 'raw_0';
			} else {
				$row_color = 'raw_1';
			}
			$valine .= "<tr width='100%'>";
			if(isset($this->queryObj->values['timestamp'][$j]))
			{
				$timestamp = $this->queryObj->values['timestamp'][$j];
			} else {
				$timestamp = date('d/M/Y H:i:s',time());
			}
			$valine .= "<td align='center' class='".$row_color."'><b>$timestamp</b></td>";
			for($i=0;$i<$columns;$i++)
			{
				$value = $this->queryObj->values['data'][$j][$i];
				if(@preg_grep("/traffic/",$type))
				{
					$value = $value * 8;
					$value = @sprintf("%8.0lf",$value);
				} else {
					$value = @sprintf("%8.0lf",$value);
				}
				$valine .="<td align='center' class='".$row_color."'>$value</td>";
			}
			if ( $col_row ==  0 )
			{
				$col_row = 1;
			} else {
				$col_row = 0;
			}
		}
		$valine .= "</tr>";
		print $valine;
		print "</table>";
		$this->make_dump_link();
	}

	function make_dump_link()
	{
		global $config;
		$enabled = read_config_option("dataquery_enable");
		$path = read_config_option("path_csv_export");
		$debug = read_config_option("dataquery_debug");
		if(!is_dir($path) && ($debug) && ($enabled))
		{
			print '<table class="dump_link" align="center">';
			print '<tr class="dump_link_tr">';
			print '<td class="dump_link_header" align="center">';
			print '<strong>Dataquery Debug::queryview:make_dump_link: $path does not exist or is not a directory</strong>';
			print '</td>';
			print '</tr>';
			print '</table>';
			exit;
		}
		if(!is_writable($path) && ($enabled) && ($debug))
		{
			print '<table class="dump_link" align="center">';
			print '<tr class="dump_link_tr">';
			print '<td class="dump_link_header" align="center">';
			print "<strong>Dataquery Debug::queryview:make_dump_link: $path is not writable</strong>";
			print '</td>';
			print '</tr>';
			print '</table>';
			exit;
		}
		if(( $enabled ) && (is_dir($path)) && (is_writable($path)))
		{
			print '<table class="dump_link" align="center">';
			print '<tr class="dump_link_tr">';
			print '<td class="dump_link_header" align="center">';
			print '[<a href="' .  $config['url_path'] . 'plugins/dataquery/dataquery.php?action=dump&local_graph_id='.$this->queryObj->local_graph_id.'&rra_id='.$this->queryObj->rra_id.'&view_type='.$this->queryObj->type.'&graph_start=' . $this->queryObj->graph_start . '&graph_end=' . $this->queryObj->graph_end . '"><strong>Dump to CSV</strong></a> ] [ <a href="'.$config['url_path'].'graph_view.php"><strong>Return</strong></a> ]<br>';
			print '</td>';
			print '</tr>';
			print '</table>';
		}
	}

	function create_download()
	{
		global $config;
		$filename = basename($this->queryObj->filename);
		$csv_path = read_config_option('path_csv_export');
		$root_dir = $_SERVER{'DOCUMENT_ROOT'};
		$dir = str_replace($root_dir, "", $csv_path);
		$filename = $dir . $filename;
		print '<table class="dump_link" align="center">';
		print '<tr class="download_link_tr">';
		print '<td class="download_link_header" align="center">File download link:</td>';
		print '</tr>';
		print '<tr>';
		print '<td class="download_link_file" align="center">'.$filename.'</td>';
		print '</tr>';
		print '<tr class="download_link_tr">';
		print '<td class="download_link_td" align="center">';
		print '<strong>[ <a href="'.$filename.'">Download</a> ] [ <a href="'.$config['url_path'].'"> Return </a> ]</strong>';
		print "</td>";
		print "</tr>";
		print "</table>";
	}

}
?>