<?php

/* vim: set expandtab tabstop=4 shiftwidth=4 softtabstop=4: */

/**
 * Setup file
 *
 * Setup file for the dataquery plugin.
 *
 * PHP versions 4 and 5
 * 
 * @category   Cactiquery
 * @package    cacti
 * @subpackage dataquery
 * @author     Kostas Petrakis aka pestilence <petrakis@insert.gr>
 * @copyright  2006 Kostas Petrakis
 * @license GNU/GPL, see LICENSE.php
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * @version $Id: setup.php 2006-10-31 15:10 pestilence $
 * @version 0.1.4a
 * @link       http://webdev.insert.gr
 */


function plugin_init_dataquery() {
	global $plugin_hooks;
	$plugin_hooks['config_arrays']['dataquery'] = 'dataquery_config_arrays';
	$plugin_hooks['config_settings']['dataquery'] = 'dataquery_config_settings';
	$plugin_hooks['draw_navigation_text']['dataquery'] = 'dataquery_draw_navigation_text';
	$plugin_hooks['graph_buttons']['dataquery'] = 'dataquery_graph_button';
}

function dataquery_version () {
	return array( 	'name' 		=> 'dataquery',
	'version' 	=> '0.1.4a',
	'longname'	=> 'Dataquery',
	'author'	=> 'Kostas Petrakis aka Pestilence',
	'homepage'	=> 'http://webdev.insert.gr',
	'email'		=> 'petrakis@insert.gr',
	'url'		=> 'http://webdev.insert.gr/dataquery/versions.php'
	);
}

function dataquery_config_arrays () {
	global $user_auth_realms, $user_auth_realm_filenames, $menu, $messages;
	$user_auth_realm_filenames['dataquery.php'] = 33;
	$user_auth_realms[33]='View Dataqueries';
}

function dataquery_config_settings () {
	global $tabs, $settings, $config;
	define('PATH_BASE', dirname(__FILE__) );
	define( 'DS', DIRECTORY_SEPARATOR );
	$csv_path = PATH_BASE . DS . "csv" . DS;
	$tabs["dataquery"] = "Dataquery";

	$settings["dataquery"] = array(
	"general_header" => array(
	"friendly_name" => "General",
	"method" => "spacer",
	),
	"path_csv_export" => array(
	"friendly_name" => "CSV Export Path",
	"description" => "Path to export CSV files <br />(<strong>Note please append a trailing slash '/' or '\' -windows users- to your path.</strong>)",
	"method" => "textbox",
	"default" => "$csv_path",
	"max_length" => "255"
	),
	"dataquery_debug" => array(
	"friendly_name" => "Enable Dataquery Debug",
	"description" => "Enable debug messages of dataquery.",
	"method" => "checkbox",
	"default" => "off"
	),
	"dataquery_enable" => array(
	"friendly_name" => "Enable CSV export",
	"description" => "Enable or disable CSV export option",
	"method" => "checkbox",
	"default" => "on"
	),
	"dataquery_type" => array(
	"friendly_name" => "The type of the query",
	"description" => "LAST,MIN,MAX,AVERAGE",
	"method" => "drop_array",
	"default" => "AVERAGE",
	"array" => array(
				"LAST" => "Latest values",
				"AVERAGE" => "Average values",
				"MAX" => "Max values",
				"MIN" => "Minimum values"
				),
	),
	"dataquery_clean" => array(
	"friendly_name" => "Clean Up old csv files",
	"description" => "To clean up old query files <a href='" . $config['url_path'] . "plugins/dataquery/dataquery.php?action=clean'>Click here</a>",
	"method" => ""
	)
	);
}

function dataquery_draw_navigation_text ($nav) {
	$nav["dataquery.php"] = array("title" => "Dataquery |current_graph_title|", "mapping" => "index.php:", "url" => "dataquery.php", "level" => "1");
	$nav["dataquery.php:query"] = array("title" => "Dataquery |current_graph_title|", "mapping" => "index.php:", "url" => "dataquery.php", "level" => "1");
	$nav["dataquery.php:dump"] = array("title" => "Dataquery dumping |current_graph_title|", "mapping" => "index.php:", "url" => "dataquery.php", "level" => "1");
	$nav["dataquery.php:clean"] = array("title" => "Dataquery Clean", "mapping" => "index.php:", "url" => "dataquery.php", "level" => "1");
	return $nav;
}

function dataquery_graph_button($data)
{
	global $config;

	$local_graph_id = $data[1]['local_graph_id'];
	$rra_id = $data[1]['rra'];
	if ((isset($_REQUEST["view_type"])) && (!empty($_REQUEST["view_type"])))
	{
		$view_type = $_REQUEST["view_type"];
	} else {
		$_REQUEST["view_type"] = "";
		$view_type = read_config_option('dataquery_type');
	}
	if ((isset($_REQUEST["graph_start"])) && (!empty($_REQUEST["graph_start"]))) 
	{
		$start=$_REQUEST["graph_start"];
	} else {
		$_REQUEST["graph_start"] = "";
		$start = time() - 3600;
	}

	if ((isset($_REQUEST["graph_end"])) && (!empty($_REQUEST["graph_end"])))
	{
		$end=$_REQUEST["graph_end"];
	} else {
		$_REQUEST["graph_end"] = "";
		$end = time();
	}
	print '<a href="' .  $config['url_path'] . 'plugins/dataquery/dataquery.php?action=query&local_graph_id='.$local_graph_id.'&rra_id='.$rra_id.'&view_type='.$view_type.'&graph_start=' . $start . '&graph_end=' . $end . '"><img src="' . $config['url_path'] . 'plugins/dataquery/images/graph_query.png" border="0" alt="Query Graph" title="Query Graph" style="padding: 3px;"></a><br>';
}

?>